<?php
/*
Plugin Name: Gestion activité
Description: Gère l'accès et l'activité des produits.
*/

// Ajouter une méta-box pour gérer l'accès au produit et son activité
function gestion_produit_meta_box() {
    add_meta_box(
        'gestion_produit_meta_box',
        __('Gestion de produit', 'gestion_activite'),
        'afficher_gestion_produit_meta_box',
        'product',
        'side',
        'default'
    );
}
add_action('add_meta_boxes', 'gestion_produit_meta_box');

// Afficher le contenu de la méta-box
function afficher_gestion_produit_meta_box($post) {
    // Récupérer les valeurs actuelles des méta "droit_acces" et "produit_actif"
    $droit_acces = get_post_meta($post->ID, 'droit_acces', true);
    $produit_actif = get_post_meta($post->ID, 'produit_actif', true);
    ?>
    <label for="droit_acces_field"><?php _e('Droit d\'accès au produit:', 'gestion_activite'); ?></label>
    <select name="droit_acces_field" id="droit_acces_field">
        <option value="membre" <?php selected($droit_acces, 'membre'); ?>><?php _e('Membre', 'gestion_activite'); ?></option>
        <option value="tout_publique" <?php selected($droit_acces, 'tout_publique'); ?>><?php _e('Tout public', 'gestion_activite'); ?></option>
    </select>
    <br>
    <label for="produit_actif_field"><?php _e('Produit actif:', 'gestion_activite'); ?></label>
    <select name="produit_actif_field" id="produit_actif_field">
        <option value="oui" <?php selected($produit_actif, 'oui'); ?>><?php _e('Oui', 'gestion_activite'); ?></option>
        <option value="non" <?php selected($produit_actif, 'non'); ?>><?php _e('Non', 'gestion_activite'); ?></option>
    </select>
    <?php
}

// Enregistrer les valeurs des méta-box
function enregistrer_gestion_produit_meta($post_id) {
    // Vérifier la sauvegarde automatique
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Vérifier la permission de l'utilisateur
    if (!current_user_can('edit_post', $post_id)) {
        return;
    }
    // Vérifier si les valeurs ont été envoyées
    if (isset($_POST['droit_acces_field'])) {
        $droit_acces = sanitize_text_field($_POST['droit_acces_field']);
        update_post_meta($post_id, 'droit_acces', $droit_acces);
    }
    if (isset($_POST['produit_actif_field'])) {
        $produit_actif = sanitize_text_field($_POST['produit_actif_field']);
        update_post_meta($post_id, 'produit_actif', $produit_actif);
    }
}
add_action('save_post', 'enregistrer_gestion_produit_meta');

// Ajouter une colonne pour afficher l'état du produit dans l'administration des produits
function ajouter_colonnes_gestion_produit($columns) {
    $columns['droit_acces'] = __('Droit d\'accès', 'gestion_activite');
    $columns['produit_actif'] = __('Produit actif', 'gestion_activite');
    return $columns;
}
add_filter('manage_product_posts_columns', 'ajouter_colonnes_gestion_produit');

// Afficher le contenu des colonnes droit_acces et produit_actif
function afficher_contenu_colonnes_gestion_produit($column, $post_id) {
    if ($column === 'droit_acces' || $column === 'produit_actif') {
        $value = get_post_meta($post_id, $column, true);
        echo $value === 'oui' ? __('Oui', 'gestion_activite') : __('Non', 'gestion_activite');
    }
}
add_action('manage_product_posts_custom_column', 'afficher_contenu_colonnes_gestion_produit', 10, 2);
